@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2016-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2016-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -30,7 +30,7 @@ from cubicweb.cwctl import CWCTL
 from cubicweb_celerytask.entities import sync_task_state
 
 from cw_celerytask_helpers.monitor import MONITOR_KEY
-from cw_celerytask_helpers.utils import get_redis_client
+from cw_celerytask_helpers.redisutils import get_redis_client
 
 logger = logging.getLogger(__name__)
 
