@@ -20,9 +20,7 @@ the cube is added to an existing instance.
 
 You could setup site properties or a workflow here for example.
 """
-import six
-
-_ = six.text_type
+_ = str
 
 wf = add_workflow(u'CeleryTask Workflow', 'CeleryTask')
 waiting = wf.add_state(_('waiting'), initial=True)
