@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2018-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2018-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -18,8 +18,8 @@
 import gzip
 
 from logilab.common.shellutils import ProgressBar
-from cw_celerytask_helpers.filelogger import get_log_filename
-from cw_celerytask_helpers.redislogger import get_task_logs, flush_task_logs
+from cw_celerytask_helpers.fileutils import get_log_filename
+from cw_celerytask_helpers.redisutils import get_task_logs, flush_task_logs
 
 
 def migrate_task_logs_to_bfss(cnx):
